@@ -124,6 +124,64 @@ class QueryOptionsMixin(object):
             self._makeoutput_columns()))
 
 
+class GroongaRecord(object):
+    def __init__(self, cls, **kwargs):
+        """Construct of GroongaRecord
+
+        :param kwargs: name and value of columns
+        """
+        object.__setattr__(self, '__cls', cls)
+        object.__setattr__(self, '__dirty', False)
+        for k, v in kwargs.items():
+            try:
+                object.__getattribute__(cls, k)
+            except AttributeError:
+                raise AttributeError('key "%s" is not defined in %s' %
+                                     (k, cls.__name__))
+            else:
+                object.__setattr__(self, k, v)
+
+    def delete(self, immediate=True):
+        """Delete the record
+
+        :param immediate: Delete the record immediately if True
+        :returns: If ``immediate`` argument is True, True if successful,
+            otherwise False. If ``immediate`` argument is False, It returns
+            :class:`SimpleQuery` object for lazy execution
+        """
+        cls = object.__getattribute__(self, '__cls')
+        query = SimpleQuery(cls).delete(id=self._id)
+        return query.execute() if immediate else query
+
+    def commit(self):
+        """Load changed data to Groonga
+
+        :returns: Number of changed data. but if data isn't changed, returns 0
+        """
+        if object.__getattribute__(self, '__dirty'):
+            object.__setattr__(self, '__dirty', False)
+            cls = object.__getattribute__(self, '__cls')
+            return LoadQuery(cls, [self]).commit()
+        else:
+            return 0
+
+    def asdict(self, excludes=tuple()):
+        result = self.__dict__.copy()
+        for attr in (tuple(excludes) + ('__cls', '__dirty')):
+            result.pop(attr, None)
+        return result
+
+    def __setattr__(self, name, value):
+        cls = object.__getattribute__(self, '__cls')
+        try:
+            object.__getattribute__(cls, name)
+        except AttributeError:
+            raise AttributeError('"%s" column is not defined in %s' %
+                                 (name, cls.__name__))
+        object.__setattr__(self, '__dirty', True)
+        object.__setattr__(self, name, value)
+
+
 class GroongaResultBase(object):
     """Base class of query result"""
 
@@ -134,7 +192,7 @@ class GroongaResultBase(object):
         :param results: query results.
         :param maxlen: maximum length of mapping results. Default is all.
         """
-        self._result = [cls(**mapped) for mapped in
+        self._result = [GroongaRecord(cls, **mapped) for mapped in
                         utils.to_python(results, 1, maxlen)]
         self._all_len = results[0][0]
 
@@ -218,6 +276,9 @@ class Suggest(object):
 class Drilldown(object):
     """Drilldown representation class"""
 
+    _key = None
+    _nsubrecs = None
+
     def __init__(self, _key=None, _nsubrecs=None):
         self._key = _key
         self._nsubrecs = _nsubrecs
@@ -338,7 +399,7 @@ class SelectQuery(SelectQueryBase):
 
     def _makeparams(self):
         params = [utils.escape('%s:@"%s"' % target) for target in
-                  self._target.items()]
+                  sorted(self._target.items())]
         param = Expression.OR.join(params)
         expr = Expression.OR.join(utils.escape(str(expr)) for expr in
                                   self._exprs)
@@ -556,16 +617,109 @@ class LoadQuery(Query):
         self._data = None
 
     def _makejson(self):
-        return utils.escape(json.dumps([v.asdict() for v in self._data]))
+        return utils.escape(json.dumps([v.asdict(excludes=('_id',)) for v in
+                                        self._data]))
 
     def __str__(self):
         return ' '.join((
             'load',
-            '--table', self._table.__name__,
+            '--table', self._table.__tablename__,
             '--input-type', 'json',
             '--values', '"%s"' % self._makejson()))
 
 
+class SimpleQuery(Query):
+    """simple true or false returning query representation class"""
+
+    def __init__(self, table_cls):
+        """Constructor of SimpleQuery
+
+        :param table_cls: Class of Table
+        """
+        super(SimpleQuery, self).__init__(table_cls)
+        self._query = []
+
+    def delete(self, key=None, id=None, filter=None):
+        """Get the 'delete' query
+
+        :param table: Table class
+        :param key: string of key of record, default is None
+        :param id: string of id of record, default is None
+        :param filter: instance of ExpressionTree or string of filter,
+            default is None
+        :returns: :class:`SimpleQuery` object
+        """
+        query = ['delete', '--table', self._table.__tablename__]
+        if key is not None:
+            query.extend(('--key', key))
+        if id is not None:
+            query.extend(('--id', str(id)))
+        if filter is not None:
+            query.extend(('--filter', '"%s"' % utils.escape(filter)))
+        self._query.extend(query)
+        return self
+
+    def truncate(self):
+        """Get the 'truncate' query
+
+        :returns: :class:`SimpleQuery` object
+        """
+        self._query = ['truncate', self._table.__tablename__]
+        return self
+
+    def cache_limit(self, max_limit=None):
+        """Get the 'cache_limit' query
+
+        :param max_limit: max number of cache limit to set.
+            If None, It returns query of returns current value of cache limit.
+            this behavior is same as Groonga
+        :returns: :class:`SimpleQuery` object
+        """
+        self._query = ['cache_limit']
+        if max_limit is not None:
+            self._query.append(str(max_limit))
+        return self
+
+    def log_level(self, level):
+        """Get the 'log_level' query
+
+        :param level: Log output level. Values are defined in
+            :class:`pyroonga.odm.attributes.LogLevel`
+        :returns: :class:`SimpleQuery` object
+        """
+        self._query = ['log_level', str(level)]
+        return self
+
+    def log_put(self, level, message):
+        """Get the 'log_put' query
+
+        :param level: Log output level. Values are defined in
+            :class:`pyroonga.odm.attributes.LogLevel`
+        :param message: string of log for output
+        :returns: :class:`SimpleQuery` object
+        """
+        self._query = ['log_level', str(level), message]
+        return self
+
+    def log_reopen(self):
+        """Get the 'log_reopen' query
+
+        :returns: :class:`SimpleQuery` object
+        """
+        self._query = ['log_reopen']
+        return self
+
+    def execute(self):
+        """execute a query
+
+        :returns: True if query is successful, otherwise False
+        """
+        return json.loads(self._table.grn.query(str(self)))
+
+    def __str__(self):
+        return ' '.join(self._query)
+
+
 class SuggestQuery(Query, QueryOptionsMixin):
     """'suggest' query representation class"""
 
@@ -725,7 +879,7 @@ class SuggestLoadQuery(LoadQuery):
     def __str__(self):
         return ' '.join((
             'load',
-            '--table', self._table.__name__,
+            '--table', self._table.__tablename__,
             '--input_type', 'json',
             '--each',
             "'suggest_preparer(_id, type, item, sequence, time, pair_query)'",
